@@ -1,6 +1,6 @@
 package App::GitGot::Command::that;
 # ABSTRACT: check if a given repository is managed
-$App::GitGot::Command::that::VERSION = '1.15';
+$App::GitGot::Command::that::VERSION = '1.16';
 use Mouse;
 extends 'App::GitGot::Command';
 use 5.010;
@@ -10,6 +10,10 @@ sub command_names { qw/ that / }
 sub _execute {
   my( $self, $opt, $args ) = @_;
   my $path = pop @$args;
+
+  defined $path and -d $path
+    or say STDERR 'ERROR: You must provide a path to a repo to check' and exit 1;
+
   $self->_path_is_managed( $path ) or exit 1;
 }
 
@@ -28,7 +32,7 @@ App::GitGot::Command::that - check if a given repository is managed
 
 =head1 VERSION
 
-version 1.15
+version 1.16
 
 =head1 AUTHOR
 
